<?php 
/**
 * Cintron functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Cintron
 */



 
if ( ! function_exists( 'cintron_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function cintron_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Cintron, use a find and replace
	 * to change 'cintron' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'cintron', CINTRON_THEME_DIR . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	
	/*
	 * Enable support for Custom Logo.
	 *
	 * @link https://developer.wordpress.org/reference/functions/add_theme_support/#custom-logo
	 */
	add_theme_support( 'custom-logo', array(
	'height'      => 90,
	'width'       => 350,
	'flex-height' => false,
	'flex-width'  => false,
	'header-text' => array( 'site-title', 'site-description' ),
	) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'cintron' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'cintron_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'cintron_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function cintron_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'cintron_content_width', 640 );
}
add_action( 'after_setup_theme', 'cintron_content_width', 0 );


if( !is_admin() ){
	function cintron_new_excerpt_more (){
		return ' &hellip;';
	}
	add_filter('excerpt_more','cintron_new_excerpt_more');

		//Edit the Excerpt lenth.
	function cintron_custom_excerpt_length ($lenth){
		return 30; // Excerpts
	}
	add_filter( 'excerpt_length', 'cintron_custom_excerpt_length' );
}



//Display meta info if enabled.
function cintron_post_meta(){ 
	if ( get_theme_mod('hide_post_meta', true) != false ) { ?>
		<ul class="post-meta">
			<li><?php cintron_entry_author(); ?></li>
			<li><?php cintron_posted_on(); ?></li>
			<li><?php cintron_entry_category(); ?></li>
			<li><?php cintron_entry_comments(); ?></li>
		</ul>
<?php }
	}


//Display Author box if enabled.
function cintron_author_box() {
		if ( get_theme_mod('hide_post_author_post_meta', true) != false  ) { ?>
			<div class="post-author-box card">
				<div class="postauthor">
					<h4><?php _e('About The Author', 'cintron'); ?></h4>
					<div class="author-box">
						<?php if(function_exists('get_avatar')) { echo get_avatar( get_the_author_meta('email'), '150' );  } ?>
						<div class="author-box-content">
							<div class="vcard clearfix">
								<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ); ?>" rel="nofollow" class="fn"><i class="fa fa-user"></i><?php the_author(); ?></a>
							</div>
							<?php if( get_the_author_meta( 'description' ) ) { ?>
								<p><?php the_author_meta('description') ?></p>
							<?php }?>
						</div>
					</div>
				</div>
			</div>		
	<?php }
}                 



?>